/* Copyright (C) 2000-2020 by Massimiliano Ghilardi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 */
#ifndef TWIN_TEST_TEST_H
#define TWIN_TEST_TEST_H

void test_stl_chars();
void test_stl_fmt();
void test_stl_utf8();
void test_stl_vector();

#endif /* TWIN_TEST_TEST_H */
